@@ -13,120 +13,62 @@ Moonshine::Parser - Parsed
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
-
-sub new {
-    my $class = shift;
-    my $self  = bless {}, $class;
-    $self->_set_up;
-    $self->SUPER::init(@_);
-}
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
     use Moonshine::Parser;
 
     my $parser = Moonshine::Parser->new();
-    my $moonshine_element = $parser->parse($html);
+    my $moonshine_element = $parser->parse('html', $html);
 
 =head1 SUBROUTINES/METHODS
 
 =head2 parse
 
+    $self->parse($type, $string);
+
+Parse html into a Moonshine::Element.
+
+=head2 parse_file
+    
+    $self->parse_file($type, $file);
+
+=cut
+
+=head2 parse_html
+
+    $self->parse_html($string);
+
 Parse html into a Moonshine::Element.
 
 =cut
 
-sub parse {
-    my ( $self, $data ) = @_;
+=head2 parse_html_file
 
-    $self->SUPER::parse($data);
-
-    return $self->{base_element};
-}
-
-=head2 parse_file
+    $self->parse_html_file($file);
 
 Parse a file that contains html into a Moonshine::Element.
 
 =cut
 
-sub parse_file {
-    my ( $self, $file ) = @_;
+=head2 parse_pod
 
-    $self->SUPER::parse_file($file);
+    $self->parse_pod($string);
 
-    return $self->{base_element};
-}
+Parse pod into a Moonshine::Element.
 
-sub start {
-    my ( $self, $tag, $attr) = @_;
-    my $closed = delete $attr->{'/'};
-   
-    $attr->{tag} = lc $tag;
-    $attr->{data} = [ ];
-    
-    my $element;
-    if ( my $current_element = $self->_current_element ) {
-        $element = $current_element->add_child($attr);
-    }
-    else {
-        $element = Moonshine::Element->new($attr);
-        if ( my $base_element = $self->{base_element} ) {
-            my $action =
-              $self->_is_closed( $base_element->{guid} )
-              ? 'add_after_element'
-              : 'add_child';
-            $base_element->$action($element);
-        }
-        else {
-            $self->{base_element} = $element;
-        }
-    }
-    push @{ $self->{elements} }, $element
-        unless $closed;
-}
+=cut
 
-sub text {
-    my ( $self, $text ) = @_;
-    if ( $text =~ m{\S+}xms ) {
-        my $element = $self->_current_element;
-        $text =~ s{^\s+|\s+$}{}g;
-        
-        if ($element->has_children) {
-            my $data = $element->children;
-            push @{ $element->{data} }, @{ $data };
-            $element->children([]);
-        }
-        
-        $element->data($text);
-    }
-}
+=head2 parse_pod_file
 
-sub end {
-    my ( $self, $tag, $origtext ) = @_;
-    my $close = pop @{ $self->{elements} };
-    push @{ $self->{closed} }, $close->{guid};
-}
+Parse a file that contains pod into a Moonshine::Element.
 
-sub _current_element {
-    my $count = scalar @{ $_[0]->{elements} };
-    return $_[0]->{elements}[ $count - 1 ];
-}
-
-sub _is_closed {
-    return grep { $_ =~ m/^$_[1]$/ } @{ $_[0]->{closed} };
-}
-
-sub _set_up {
-    $_[0]->{base_element} = undef;
-    $_[0]->{elements}     = [];
-    $_[0]->{closed}       = [];
-}
+=cut
 
 =head1 AUTHOR
 
